@@ -1,3 +1,2 @@
 #Version of simplyhack
-
-__version__ = 1.0.0
+import simplyhack
